Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EasyLog ¶
type EasyLog struct {
SaveDir string
FileName string
MaxFileSize int64
MaxFileCount int64
FlushFreq time.Duration
Pipe chan *bytes.Buffer
// contains filtered or unexported fields
}
func (*EasyLog) SetMaxFileCount ¶
set max log file count if MaxFileCount == 0, no file count limited. if MaxFileCount > 0 and actual file count > MaxFileCount, then the earliest log file will be deleted.
func (*EasyLog) SetMaxFileSize ¶
set single file max size. if the file size exceeds MaxFileSize, then a new file will be created to store log info
Click to show internal directories.
Click to hide internal directories.